@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
 import os
 import math
@@ -107,22 +107,14 @@ class _tiles:
         "http://tile.stamen.com/toner-lines/{z}/{x}/{y}.png", 
         "OpenStreetMap, Toner Lines",
         *_osm_copyright)
-    osm_tonner_backgrounds = Tile(
-        "http://tile.stamen.com/toner-backgrounds/{z}/{x}/{y}.png", 
+    osm_tonner_background = Tile(
+        "http://tile.stamen.com/toner-background/{z}/{x}/{y}.png", 
         "OpenStreetMap, Toner Backgrounds",
         *_osm_copyright)
     osm_tonner_lite = Tile(
         "http://tile.stamen.com/toner-lite/{z}/{x}/{y}.png", 
         "OpenStreetMap, Toner Lite",
         *_osm_copyright)
-    osm_tonner_lite = Tile(
-        "http://tile.stamen.com/toner-lite/{z}/{x}/{y}.png", 
-        "OpenStreetMap, Toner Lite",
-        *_osm_copyright)
-    osm_tonner_lite = Tile(
-        "http://tile.stamen.com/toner-lite/{z}/{x}/{y}.png", 
-        "OpenStreetMap, Toner Lite",
-        *_osm_copyright)
 
     # Geospatial Information Authority of Japan
     # https://maps.gsi.go.jp/development/ichiran.html
@@ -139,7 +131,7 @@ class _tiles:
         "Geospatial Information Authority of Japan, Pale",
         *_japangsi_copyright)
     japangsi_blank = Tile(
-        "https://cyberjapandata.gsi.go.jp/xyz/blank/{z}/{x}/{y}.png"
+        "https://cyberjapandata.gsi.go.jp/xyz/blank/{z}/{x}/{y}.png",
         "Geospatial Information Authority of Japan, Blank",
         *_japangsi_copyright)
 
@@ -315,7 +307,7 @@ def _crs_from_str(s):
     else:
         raise ValueError("'%' is not supported CRS string" % s)
 
-def get_maparray(bounds: tuple, tile: _Tile="osm", z: int=None, extent_crs="lonlat", use_cache:bool =True)-> tuple:
+def get_maparray(bounds: tuple, tile: _Tile="osm", z: int=None, extent_crs="lonlat", use_cache:bool =True, verbose: int=1)-> tuple:
     """
     Draw map on matlotlib axes.
 
@@ -332,7 +324,7 @@ def get_maparray(bounds: tuple, tile: _Tile="osm", z: int=None, extent_crs="lonl
                      - "webmap", "web-mercator" or "epsg:3857" --> indices in EPSG:3857 system (Web Mercator)
         use_cache  : Bool. If True, map images stored in the internal database are used. This helps to reduce the
                     number of web requests to the map tile servers.
-        kwargs     : Optional arguments passed to ax.imshow() or plt.imshow()
+        verbose  : Int. 0: print no message, 1: print the auto-chozen zoom level, 2 or larger: show the url of the tiles
     
     Returns:
         Tuple of
@@ -357,7 +349,8 @@ def get_maparray(bounds: tuple, tile: _Tile="osm", z: int=None, extent_crs="lonl
     # make sure (lon1, lat1) is top-left, (lon2, lat2) is bottom-right
     if z is None:
         z = _auto_zoom(lon1, lon2)
-        print("Zoom level %d is chosen" % z, file=sys.stderr)
+        if verbose >= 1:
+            print("Zoom level %d is chosen" % z, file=sys.stderr)
 
     # find tiles of the corners
     (x1, y1, i1, j1) = _get_tile_index(lon1, lat1, z)
@@ -371,7 +364,8 @@ def get_maparray(bounds: tuple, tile: _Tile="osm", z: int=None, extent_crs="lonl
         row = []
         for x in xs:
             url = tile.baseurl.format(x=x, y=y, z=z)
-            #print(url, file=sys.stderr)
+            if verbose >= 2:
+                print(url, file=sys.stderr)
             img = _get_tileimage(url, use_cache=use_cache)
             row.append(np.asarray(img))
         out.append(np.concatenate(row, axis=1))
@@ -387,7 +381,7 @@ def get_maparray(bounds: tuple, tile: _Tile="osm", z: int=None, extent_crs="lonl
 
 def draw_map(bounds: tuple, tile: Tile="osm", z: int=None, aspect="auto",
              extent_crs="lonlat", scaling: bool=False,
-             use_cache:bool =True, ax=None, **kwargs)-> tuple:
+             use_cache:bool =True, verbose: int=1, ax=None, **kwargs)-> tuple:
     """
     Draw map on matlotlib axes.
 
@@ -409,6 +403,7 @@ def draw_map(bounds: tuple, tile: Tile="osm", z: int=None, aspect="auto",
                      - "webmap", "web-mercator" or "epsg:3857" --> indices in EPSG:3857 system (Web Mercator)
         use_cache: Bool. If True, map images stored in the internal database are used. This helps to reduce the
                     number of web requests to the map tile servers.
+        verbose  : Int. 0: print no message, 1: print the auto-chozen zoom level, 2 or larger: show the url of the tiles
         ax       : If given, map image is to drawn on this axes, and autoscale is disabled.
         kwargs   : Optional arguments passed to ax.imshow() or plt.imshow()
     
@@ -417,7 +412,7 @@ def draw_map(bounds: tuple, tile: Tile="osm", z: int=None, aspect="auto",
         - Axes object
         - AxesImage object
     """
-    array, extent = get_maparray(bounds, tile, z, use_cache=use_cache, extent_crs=extent_crs)
+    array, extent = get_maparray(bounds, tile, z, use_cache=use_cache, extent_crs=extent_crs, verbose=verbose)
     #print(extent)
     if "extent" in kwargs:
         extent = kwargs.pop("extent")
@@ -453,4 +448,4 @@ def draw_map(bounds: tuple, tile: Tile="osm", z: int=None, aspect="auto",
         ax_img = ax.imshow(array, **opts)
         ax.set_ylim((extent[2], extent[3]), auto=False)
     
-    return ax, ax_img
\ No newline at end of file
+    return ax, ax_img
